@@ -46,7 +46,10 @@ from .models.summary_statistics import (
 from .models.branch import BranchName
 from .models.checks import Check, CheckCreationRequest, CheckId
 from .models.cluster import Cluster, ClusterId, ClusterName
-from .models.commit import Commit, CommitId
+from .models.commit import (
+    Commit, CommitId, EntityCreatedUpdated, EntityMappingCreatedUpdated, EntityPopulationCreatedUpdated,
+    FeatureCreatedUpdated, FeatureSetCreatedUpdated, TemplateCreatedUpdated, TableCreatedUpdated
+)
 from .models.destination import (
     Destination, BigQueryDestination, GCSDestination, HDFSDestination, LocalDestination, S3ADestination,
     S3Destination, DestinationId, DestinationName
@@ -213,7 +216,92 @@ class Anaml:
         result = self._json_or_handle_errors(r)
         return Commit.from_json(result)
 
-    # Cluster-related functions
+    def get_branches(self) -> List[str]:
+        """Get a list of all branches.
+
+        Returns:
+            A list of branch names
+        """
+        r = self._get("/branch")
+        result = self._json_or_handle_errors(r)
+        return result
+
+    def get_recently_modified_entities(self) -> List[EntityCreatedUpdated]:
+        """Get recently modified entity ids, with created and updated timestamps.
+
+        Returns:
+            A list of entity ids with created and updated timestamps
+            associated with the given commit and recently modified.
+        """
+        r = self._get("/blame/entity")
+        result = self._json_or_handle_errors(r)
+        return [EntityCreatedUpdated.from_json(d) for d in result]
+
+    def get_recently_modified_entity_mappings(self) -> List[EntityMappingCreatedUpdated]:
+        """Get recently modified entity mapping ids, with created and updated timestamps.
+
+        Returns:
+            A list of entity mapping ids with created and updated timestamps
+            associated with the given commit and recently modified.
+        """
+        r = self._get("/blame/entity-mapping")
+        result = self._json_or_handle_errors(r)
+        return [EntityMappingCreatedUpdated.from_json(d) for d in result]
+
+    def get_recently_modified_entity_populations(self) -> List[EntityPopulationCreatedUpdated]:
+        """Get recently modified entity population ids, with created and updated timestamps.
+
+        Returns:
+            A list of entity population ids with created and updated timestamps
+            associated with the given commit and recently modified.
+        """
+        r = self._get("/blame/entity-population")
+        result = self._json_or_handle_errors(r)
+        return [EntityPopulationCreatedUpdated.from_json(d) for d in result]
+
+    def get_recently_modified_features(self) -> List[FeatureCreatedUpdated]:
+        """Get recently modified feature ids, with created and updated timestamps.
+
+        Returns:
+            A list of feature ids with created and updated timestamps
+            associated with the given commit and recently modified.
+        """
+        r = self._get("/blame/feature")
+        result = self._json_or_handle_errors(r)
+        return [FeatureCreatedUpdated.from_json(d) for d in result]
+
+    def get_recently_modified_feature_sets(self) -> List[FeatureSetCreatedUpdated]:
+        """Get recently modified feature set ids, with created and updated timestamps.
+
+        Returns:
+            A list of feature set ids with created and updated timestamps
+            associated with the given commit and recently modified.
+        """
+        r = self._get("/blame/feature-set")
+        result = self._json_or_handle_errors(r)
+        return [FeatureSetCreatedUpdated.from_json(d) for d in result]
+
+    def get_recently_modified_feature_templates(self) -> List[TemplateCreatedUpdated]:
+        """Get recently modified feature template ids, with created and updated timestamps.
+
+        Returns:
+            A list of feature template ids with created and updated timestamps
+            associated with the given commit and recently modified.
+        """
+        r = self._get("/blame/feature-template")
+        result = self._json_or_handle_errors(r)
+        return [TemplateCreatedUpdated.from_json(d) for d in result]
+
+    def get_recently_modified_tables(self) -> List[TableCreatedUpdated]:
+        """Get recently modified table ids, with created and updated timestamps.
+
+        Returns:
+            A list of table ids with created and updated timestamps
+            associated with the given commit and recently modified.
+        """
+        r = self._get("/blame/table")
+        result = self._json_or_handle_errors(r)
+        return [TableCreatedUpdated.from_json(d) for d in result]
 
     def get_clusters(self) -> List[Cluster]:
         """Get a list of clusters from the Anaml server.
@@ -335,7 +423,7 @@ class Anaml:
 
     def preview_feature(
             self,
-            feature: Union[List[Feature], Feature],
+            feature: Feature,
             *,
             entity: Optional[EntityId] = None,
             snapshot_date: Optional[Union[str, date]] = None
@@ -347,10 +435,7 @@ class Anaml:
             entity:  Entity Id to filter feature preview on.
             snapshot_date: Date to filter feature preview on.
         """
-        if isinstance(feature, list):
-            req = {"features": [f.to_json() for f in feature]}
-        else:
-            req = {"features": [feature.to_json()]}
+        req = {"feature": feature.to_json()}
 
         req["entity"] = entity
 
@@ -374,7 +459,7 @@ class Anaml:
 
     def preview_feature_and_plot(
             self,
-            feature: Union[List[Feature], Feature],
+            feature: Feature,
             *,
             entity: Optional[EntityId] = None,
             snapshot_date: Optional[Union[str, datetime.date]] = None
@@ -404,7 +489,7 @@ class Anaml:
         """
         import pandas
 
-        r = self._post("/feature-sample", json={"features": [feature.to_json()]})
+        r = self._post("/feature-sample", json={"feature": feature.to_json()})
         result = self._json_or_handle_errors(r)
 
         return pandas.DataFrame(result)
